### Analisis de secuencias ChIP-seq

Herramientas para análisis de secuencias en resultados de ChIP-seq.

Incluye: 
Clase para buscar secuencias en resultados de ChIP-seq y en promotores del genoma.
Funciones para buscar sitios de union en listas de secuencias.
Generacion de archivos .csv con resultados e histogramas.
